==> deepin-deepinid-plugin_2.0.8.tar.xz: BUILD/translations/dcc-deepinid-plugin.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>LoginInfoPage</name>
    <message>
        <source>Edit account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The nickname must be 1~32 characters long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The full name is too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mainland China</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other regions</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SyncModule</name>
    <message>
        <source>deepin ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>UOS ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cloud sync, app store and etc</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TransString</name>
    <message>
        <source>deepin Cloud Sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subject to your local laws and regulations, it is currently unavailable in your region.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Securely store system settings and personal data in the cloud, and keep them in sync across devices.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Launcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wallpaper</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear cloud data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to clear your system settings and personal data saved in the cloud?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Once the data is cleared, it cannot be recovered!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Syncing...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last sync: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link local accounts to deepin ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If linked, you can use deepin ID to log in and reset passwords of local accounts. Switch it off to get them unlinked.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trusted devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage trusted devices to keep your deepin ID secure.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OS version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to
remove this device from trusted devices?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cloud Service of deepin ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage your deepin ID and sync your personal data across devices.
Sign in to deepin ID to get personalized features and services of Browser, App Store, Support, and more.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sign In to deepin ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>deepin Cloud</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Devices and Local Accounts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Account Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The feature is not available at present, please activate your system first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trusted phone numbers and email addresses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the trusted mobile number or email address to sign in to deepin ID, and verify sensitive operations if they are performed on deepin ID.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link phone number to deepin ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link email address to deepin ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link third-party accounts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Securely and quickly log in to your deepin ID and local account by scanning the QR code with the linked WeChat.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If unlinked, you will not be able to use WeChat to sign in to deepin ID.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to unlink it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change your deepin ID password regularly to ensure its security.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operation failed, please try later</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operation Successful</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset password successfully</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Phone number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Email address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter a correct phone number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter a correct email address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use another phone number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use another email address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unlink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unlinked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wrong password, %1 chances left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The login error has reached the limit today. You can reset the password and try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The phone number has been linked to deepin ID: %1.
Please check and choose one action below.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The email address has been linked to deepin ID: %1.
Please check and choose one action below.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Security Verification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The action is sensitive, please enter the login password first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change deepin ID password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link to current deepin ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set a Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Verification code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resend (%1s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter a correct verification code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link WeChat to deepin ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scan QR code with WeChat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password must contain numbers and letters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password must be between 8 and 64 characters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8-64 characters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Passwords don&apos;t match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Repeat the password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8-64 characters, including uppercase or lowercase English letters and numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid nickname, please enter a new one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The nickname cannot contain special characters (&apos;&lt;&gt;&amp;&quot;) and whitespaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The nickname can be modified only once a day</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> deepin-deepinid-plugin_2.0.9.tar.xz: BUILD/translations/dcc-deepinid-plugin.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>LoginInfoPage</name>
    <message>
        <source>Edit account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The nickname must be 1~32 characters long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The full name is too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mainland China</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other regions</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SyncModule</name>
    <message>
        <source>deepin ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>UOS ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cloud sync, app store and etc</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TransString</name>
    <message>
        <source>deepin Cloud Sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subject to your local laws and regulations, it is currently unavailable in your region.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Securely store system settings and personal data in the cloud, and keep them in sync across devices.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Launcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wallpaper</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear cloud data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to clear your system settings and personal data saved in the cloud?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Once the data is cleared, it cannot be recovered!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Syncing...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last sync: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link local accounts to deepin ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If linked, you can use deepin ID to log in and reset passwords of local accounts. Switch it off to get them unlinked.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trusted devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage trusted devices to keep your deepin ID secure.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OS version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to
remove this device from trusted devices?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cloud Service of deepin ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage your deepin ID and sync your personal data across devices.
Sign in to deepin ID to get personalized features and services of Browser, App Store, and more.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sign In to deepin ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>deepin Cloud</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Devices and Local Accounts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Account Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The feature is not available at present, please activate your system first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trusted phone numbers and email addresses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the trusted mobile number or email address to sign in to deepin ID, and verify sensitive operations if they are performed on deepin ID.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link phone number to deepin ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link email address to deepin ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link third-party accounts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Securely and quickly log in to your deepin ID and local account by scanning the QR code with the linked WeChat.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If unlinked, you will not be able to use WeChat to sign in to deepin ID.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to unlink it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change your deepin ID password regularly to ensure its security.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operation failed, please try later</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operation Successful</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset password successfully</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Phone number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Email address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter a correct phone number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter a correct email address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use another phone number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use another email address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unlink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unlinked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wrong password, %1 chances left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The login error has reached the limit today. You can reset the password and try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The phone number has been linked to deepin ID: %1.
Please check and choose one action below.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The email address has been linked to deepin ID: %1.
Please check and choose one action below.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Security Verification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The action is sensitive, please enter the login password first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change deepin ID password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link to current deepin ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set a Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Verification code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resend (%1s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter a correct verification code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link WeChat to deepin ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scan QR code with WeChat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password must contain numbers and letters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password must be between 8 and 64 characters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8-64 characters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Passwords don&apos;t match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Repeat the password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8-64 characters, including uppercase or lowercase English letters and numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid nickname, please enter a new one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The nickname cannot contain special characters (&apos;&lt;&gt;&amp;&quot;) and whitespaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The nickname can be modified only once a day</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
